==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/RootDeviceHintsFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RootDeviceHintsFluent<A extends RootDeviceHintsFluent<A>> extends BaseFluent<A>{
  public RootDeviceHintsFluent() {
  }
  
  public RootDeviceHintsFluent(RootDeviceHints instance) {
    this.copyInstance(instance);
  }
  private String deviceName;
  private String hctl;
  private Integer minSizeGigabytes;
  private String model;
  private Boolean rotational;
  private String serialNumber;
  private String vendor;
  private String wwn;
  private String wwnVendorExtension;
  private String wwnWithExtension;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RootDeviceHints instance) {
    instance = (instance != null ? instance : new RootDeviceHints());
  
    if (instance != null) {
        this.withDeviceName(instance.getDeviceName());
        this.withHctl(instance.getHctl());
        this.withMinSizeGigabytes(instance.getMinSizeGigabytes());
        this.withModel(instance.getModel());
        this.withRotational(instance.getRotational());
        this.withSerialNumber(instance.getSerialNumber());
        this.withVendor(instance.getVendor());
        this.withWwn(instance.getWwn());
        this.withWwnVendorExtension(instance.getWwnVendorExtension());
        this.withWwnWithExtension(instance.getWwnWithExtension());
        this.withDeviceName(instance.getDeviceName());
        this.withHctl(instance.getHctl());
        this.withMinSizeGigabytes(instance.getMinSizeGigabytes());
        this.withModel(instance.getModel());
        this.withRotational(instance.getRotational());
        this.withSerialNumber(instance.getSerialNumber());
        this.withVendor(instance.getVendor());
        this.withWwn(instance.getWwn());
        this.withWwnVendorExtension(instance.getWwnVendorExtension());
        this.withWwnWithExtension(instance.getWwnWithExtension());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDeviceName() {
    return this.deviceName;
  }
  
  public A withDeviceName(String deviceName) {
    this.deviceName=deviceName; return (A) this;
  }
  
  public boolean hasDeviceName() {
    return this.deviceName != null;
  }
  
  public String getHctl() {
    return this.hctl;
  }
  
  public A withHctl(String hctl) {
    this.hctl=hctl; return (A) this;
  }
  
  public boolean hasHctl() {
    return this.hctl != null;
  }
  
  public Integer getMinSizeGigabytes() {
    return this.minSizeGigabytes;
  }
  
  public A withMinSizeGigabytes(Integer minSizeGigabytes) {
    this.minSizeGigabytes=minSizeGigabytes; return (A) this;
  }
  
  public boolean hasMinSizeGigabytes() {
    return this.minSizeGigabytes != null;
  }
  
  public String getModel() {
    return this.model;
  }
  
  public A withModel(String model) {
    this.model=model; return (A) this;
  }
  
  public boolean hasModel() {
    return this.model != null;
  }
  
  public Boolean getRotational() {
    return this.rotational;
  }
  
  public A withRotational(Boolean rotational) {
    this.rotational=rotational; return (A) this;
  }
  
  public boolean hasRotational() {
    return this.rotational != null;
  }
  
  public String getSerialNumber() {
    return this.serialNumber;
  }
  
  public A withSerialNumber(String serialNumber) {
    this.serialNumber=serialNumber; return (A) this;
  }
  
  public boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  public String getVendor() {
    return this.vendor;
  }
  
  public A withVendor(String vendor) {
    this.vendor=vendor; return (A) this;
  }
  
  public boolean hasVendor() {
    return this.vendor != null;
  }
  
  public String getWwn() {
    return this.wwn;
  }
  
  public A withWwn(String wwn) {
    this.wwn=wwn; return (A) this;
  }
  
  public boolean hasWwn() {
    return this.wwn != null;
  }
  
  public String getWwnVendorExtension() {
    return this.wwnVendorExtension;
  }
  
  public A withWwnVendorExtension(String wwnVendorExtension) {
    this.wwnVendorExtension=wwnVendorExtension; return (A) this;
  }
  
  public boolean hasWwnVendorExtension() {
    return this.wwnVendorExtension != null;
  }
  
  public String getWwnWithExtension() {
    return this.wwnWithExtension;
  }
  
  public A withWwnWithExtension(String wwnWithExtension) {
    this.wwnWithExtension=wwnWithExtension; return (A) this;
  }
  
  public boolean hasWwnWithExtension() {
    return this.wwnWithExtension != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RootDeviceHintsFluent that = (RootDeviceHintsFluent) o;
    if (!java.util.Objects.equals(deviceName, that.deviceName)) return false;
  
    if (!java.util.Objects.equals(hctl, that.hctl)) return false;
  
    if (!java.util.Objects.equals(minSizeGigabytes, that.minSizeGigabytes)) return false;
  
    if (!java.util.Objects.equals(model, that.model)) return false;
  
    if (!java.util.Objects.equals(rotational, that.rotational)) return false;
  
    if (!java.util.Objects.equals(serialNumber, that.serialNumber)) return false;
  
    if (!java.util.Objects.equals(vendor, that.vendor)) return false;
  
    if (!java.util.Objects.equals(wwn, that.wwn)) return false;
  
    if (!java.util.Objects.equals(wwnVendorExtension, that.wwnVendorExtension)) return false;
  
    if (!java.util.Objects.equals(wwnWithExtension, that.wwnWithExtension)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(deviceName,  hctl,  minSizeGigabytes,  model,  rotational,  serialNumber,  vendor,  wwn,  wwnVendorExtension,  wwnWithExtension,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (hctl != null) { sb.append("hctl:"); sb.append(hctl + ","); }
    if (minSizeGigabytes != null) { sb.append("minSizeGigabytes:"); sb.append(minSizeGigabytes + ","); }
    if (model != null) { sb.append("model:"); sb.append(model + ","); }
    if (rotational != null) { sb.append("rotational:"); sb.append(rotational + ","); }
    if (serialNumber != null) { sb.append("serialNumber:"); sb.append(serialNumber + ","); }
    if (vendor != null) { sb.append("vendor:"); sb.append(vendor + ","); }
    if (wwn != null) { sb.append("wwn:"); sb.append(wwn + ","); }
    if (wwnVendorExtension != null) { sb.append("wwnVendorExtension:"); sb.append(wwnVendorExtension + ","); }
    if (wwnWithExtension != null) { sb.append("wwnWithExtension:"); sb.append(wwnWithExtension + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRotational() {
    return withRotational(true);
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/RootDeviceHintsFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class RootDeviceHintsFluent<A extends RootDeviceHintsFluent<A>> extends BaseFluent<A>{
  public RootDeviceHintsFluent() {
  }
  
  public RootDeviceHintsFluent(RootDeviceHints instance) {
    this.copyInstance(instance);
  }
  private String deviceName;
  private String hctl;
  private Integer minSizeGigabytes;
  private String model;
  private Boolean rotational;
  private String serialNumber;
  private String vendor;
  private String wwn;
  private String wwnVendorExtension;
  private String wwnWithExtension;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(RootDeviceHints instance) {
    instance = (instance != null ? instance : new RootDeviceHints());
    if (instance != null) {
          this.withDeviceName(instance.getDeviceName());
          this.withHctl(instance.getHctl());
          this.withMinSizeGigabytes(instance.getMinSizeGigabytes());
          this.withModel(instance.getModel());
          this.withRotational(instance.getRotational());
          this.withSerialNumber(instance.getSerialNumber());
          this.withVendor(instance.getVendor());
          this.withWwn(instance.getWwn());
          this.withWwnVendorExtension(instance.getWwnVendorExtension());
          this.withWwnWithExtension(instance.getWwnWithExtension());
          this.withDeviceName(instance.getDeviceName());
          this.withHctl(instance.getHctl());
          this.withMinSizeGigabytes(instance.getMinSizeGigabytes());
          this.withModel(instance.getModel());
          this.withRotational(instance.getRotational());
          this.withSerialNumber(instance.getSerialNumber());
          this.withVendor(instance.getVendor());
          this.withWwn(instance.getWwn());
          this.withWwnVendorExtension(instance.getWwnVendorExtension());
          this.withWwnWithExtension(instance.getWwnWithExtension());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDeviceName() {
    return this.deviceName;
  }
  
  public A withDeviceName(String deviceName) {
    this.deviceName = deviceName;
    return (A) this;
  }
  
  public boolean hasDeviceName() {
    return this.deviceName != null;
  }
  
  public String getHctl() {
    return this.hctl;
  }
  
  public A withHctl(String hctl) {
    this.hctl = hctl;
    return (A) this;
  }
  
  public boolean hasHctl() {
    return this.hctl != null;
  }
  
  public Integer getMinSizeGigabytes() {
    return this.minSizeGigabytes;
  }
  
  public A withMinSizeGigabytes(Integer minSizeGigabytes) {
    this.minSizeGigabytes = minSizeGigabytes;
    return (A) this;
  }
  
  public boolean hasMinSizeGigabytes() {
    return this.minSizeGigabytes != null;
  }
  
  public String getModel() {
    return this.model;
  }
  
  public A withModel(String model) {
    this.model = model;
    return (A) this;
  }
  
  public boolean hasModel() {
    return this.model != null;
  }
  
  public Boolean getRotational() {
    return this.rotational;
  }
  
  public A withRotational(Boolean rotational) {
    this.rotational = rotational;
    return (A) this;
  }
  
  public boolean hasRotational() {
    return this.rotational != null;
  }
  
  public String getSerialNumber() {
    return this.serialNumber;
  }
  
  public A withSerialNumber(String serialNumber) {
    this.serialNumber = serialNumber;
    return (A) this;
  }
  
  public boolean hasSerialNumber() {
    return this.serialNumber != null;
  }
  
  public String getVendor() {
    return this.vendor;
  }
  
  public A withVendor(String vendor) {
    this.vendor = vendor;
    return (A) this;
  }
  
  public boolean hasVendor() {
    return this.vendor != null;
  }
  
  public String getWwn() {
    return this.wwn;
  }
  
  public A withWwn(String wwn) {
    this.wwn = wwn;
    return (A) this;
  }
  
  public boolean hasWwn() {
    return this.wwn != null;
  }
  
  public String getWwnVendorExtension() {
    return this.wwnVendorExtension;
  }
  
  public A withWwnVendorExtension(String wwnVendorExtension) {
    this.wwnVendorExtension = wwnVendorExtension;
    return (A) this;
  }
  
  public boolean hasWwnVendorExtension() {
    return this.wwnVendorExtension != null;
  }
  
  public String getWwnWithExtension() {
    return this.wwnWithExtension;
  }
  
  public A withWwnWithExtension(String wwnWithExtension) {
    this.wwnWithExtension = wwnWithExtension;
    return (A) this;
  }
  
  public boolean hasWwnWithExtension() {
    return this.wwnWithExtension != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RootDeviceHintsFluent that = (RootDeviceHintsFluent) o;
    if (!java.util.Objects.equals(deviceName, that.deviceName)) return false;
    if (!java.util.Objects.equals(hctl, that.hctl)) return false;
    if (!java.util.Objects.equals(minSizeGigabytes, that.minSizeGigabytes)) return false;
    if (!java.util.Objects.equals(model, that.model)) return false;
    if (!java.util.Objects.equals(rotational, that.rotational)) return false;
    if (!java.util.Objects.equals(serialNumber, that.serialNumber)) return false;
    if (!java.util.Objects.equals(vendor, that.vendor)) return false;
    if (!java.util.Objects.equals(wwn, that.wwn)) return false;
    if (!java.util.Objects.equals(wwnVendorExtension, that.wwnVendorExtension)) return false;
    if (!java.util.Objects.equals(wwnWithExtension, that.wwnWithExtension)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(deviceName,  hctl,  minSizeGigabytes,  model,  rotational,  serialNumber,  vendor,  wwn,  wwnVendorExtension,  wwnWithExtension,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (deviceName != null) { sb.append("deviceName:"); sb.append(deviceName + ","); }
    if (hctl != null) { sb.append("hctl:"); sb.append(hctl + ","); }
    if (minSizeGigabytes != null) { sb.append("minSizeGigabytes:"); sb.append(minSizeGigabytes + ","); }
    if (model != null) { sb.append("model:"); sb.append(model + ","); }
    if (rotational != null) { sb.append("rotational:"); sb.append(rotational + ","); }
    if (serialNumber != null) { sb.append("serialNumber:"); sb.append(serialNumber + ","); }
    if (vendor != null) { sb.append("vendor:"); sb.append(vendor + ","); }
    if (wwn != null) { sb.append("wwn:"); sb.append(wwn + ","); }
    if (wwnVendorExtension != null) { sb.append("wwnVendorExtension:"); sb.append(wwnVendorExtension + ","); }
    if (wwnWithExtension != null) { sb.append("wwnWithExtension:"); sb.append(wwnWithExtension + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRotational() {
    return withRotational(true);
  }
  

}
